package Profiler;
import java.util.*;

/**
 * CheckPoint used as a data structure
 * 
 * @author Jorge Albaladejo
 * @version 1.0
 */
public class CheckPoint {

	/** 
	 * Name for this checkpoint
	 */
	private String name = null;
	private long start = 0;
	private long end = 0;
	
	/**
	 * Main constructor
	 * 
	 * @param name for this checkpoint
	 */
	public CheckPoint(String name ) {
		this.name = name;
		this.start = System.nanoTime();
	}
	
	/**
	 * Ends this checkpoint
	 */
	public void end() {
		this.end = System.nanoTime();
	}

	/**
	 * Returns the time taken by the checkpoint
	 * @return long milliseconds taken by the checkpoint
	 */
	public long duration() {
		try {
			return this.end - this.start ;
		} catch (Exception e) {
			return 0;
		}
	}
	
	/**
	 * Getter for start
	 * 
	 * @return long
	 */
	public long getStart() {
		return this.start;
	}
	
	/**
	 * Getter for name
	 * 
	 * @return String
	 */
	public String getName() {
		return this.name;
	}
	
	/**
	 * String representation
	 * 
	 * @return String
	 */
	public String toString() {
		if (this.duration() > 0){
			return String.format("<br />\n" + this.getStart() + " >> " + this.name + " took %10.3f milliseconds", this.duration() / 1E6 );
		}	
		
		return "";
	}
}
