package Profiler;
import java.util.*;

/**
 * Helps to create hystograms
 * 
 * @author Jorge Albaladejo
 * @version 1.0
 */
public class Hystogram {
	
	private Vector items = null;

	/**
	 * Main constructor
	 * 
	 * @param name for this checkpoint
	 */
	public Hystogram() {
		this.items = new Vector();
	}
	
	/**
	 * Adds a checkpoint to the hystogram
	 * 
	 * @param cp CheckPoint
	 */
	public void add(CheckPoint cp){
		
		int index = this.hasCheckPoint(cp);
		HystogramItem hi = null;
		
		if ( index == -1) { // does not exist, create it			
			
			this.items.add(new HystogramItem(cp));			
			
		} else { // increment counter and time
					
			hi = (HystogramItem) this.items.get(index);
			hi.increment();
			hi.addTime(cp.duration());			
		
		}
	}
	
	/**
	 * Checks if the checkpoint has already been registered with an item
	 * 	Returns the item index on the items vector if already exists
	 * 	and -1 otherwise
	 * 
	 * @param cp CheckPoint
	 * 
	 * @return int
	 */
	private int hasCheckPoint(CheckPoint cp) {
		int size = this.items.size();
		HystogramItem hi = null;
		
		for (int i = 0; i < size; i++) {
			if ( this.items.get(i) instanceof HystogramItem ) {
				
				hi = (HystogramItem) this.items.get(i);
				
				// group by CheckPoint name
				if ( hi.getName().equals( cp.getName() ) ) {
					return i;					
				}
			}			
		}
		
		return -1;
	}
	
	/**
	 * Gets an hystogram with occurences and total consumption of each checkpoint
	 * 
	 * @param long total duration for percentiles
	 * 
	 * @return String
	 */
	public String toString(long duration) {
		
		String result = "<h3>Profiler information</h3>\n";
					
		int size = this.items.size();
		HystogramItem hi = null;
		
		// header
		result += "<table><tr><th>CheckPoint</th><th>Frequency</th><th>Time</th><th>% Time</th></tr>";
		
		for (int i = 0; i < size; i++) {
			if ( this.items.get(i) instanceof HystogramItem ) {
				
				hi = (HystogramItem) this.items.get(i);
				
				result += hi.toString(duration);
			}			
		}
		
		// footer
		result += "</table>";

		return result;
	}

}
