package Profiler;
import java.util.*;

/**
 * Hystogram Item used as a data structure
 * 
 * @author Jorge Albaladejo
 * @version 1.0
 */
public class HystogramItem {

	/** 
	 * Name for this checkpoint
	 */
	private String name = null;
	private int count = 0;
	private long time = 0;
	
	/**
	 * Main constructor
	 * 
	 * @param name for this checkpoint
	 */
	public HystogramItem(CheckPoint cp ) {
		this.name = cp.getName();
		this.time = cp.duration();
		this.count = 1;
	}
	
	/**
	 * Getter for name
	 * 
	 * @return String
	 */
	public String getName() {
		return this.name;
	}
	
	/**
	 * Increments counter
	 */
	public void increment() {
		this.count++;		
	}
	
	/** 
	 * Increments time value
	 */
	public void addTime(long time) {
		this.time += time;		
	}
	
	/**
	 * String representation
	 * 
	 * @param long total duration for percentiles
	 * 
	 * @return String
	 */
	public String toString(long duration) {
		
		if (this.count > 0 && this.time > 0){
			
			return String.format("\n<tr><td>" + this.name + "</td><td>" + this.count + "</td><td>%10.3f</td><td>%6.2f%%</td></tr>", this.time / 1E6, 100 * (float) this.time / (float) duration );
			
		}	
		
		return "";
	}

}
