package Profiler;
import java.util.*;

/**
 * Calculates microseconds from a starting date for debugging purposes
 * 
 * @author Jorge Albaladejo
 * @version 1.0
 */
public class Profiler {
	
	private long startDate = 0;
	private long endDate = 0;
	private Vector checkPoints = null;
	private Hystogram hystogram = null;
	    
	/**
	 * Constructor
	 */
	public Profiler() {
		this.startDate = System.nanoTime();
		this.endDate = System.nanoTime();
		this.checkPoints = new Vector();
		this.hystogram = new Hystogram();
	}
	
	/**
	 * Starts the timer
	 */
	public void start() {
	    this.startDate = System.nanoTime();
	}
	
	/**
	 * Ends the timer
	 */
	public void end() {
	    this.endDate = System.nanoTime();
	}
	
	/**
	 * Creates a checkpoint
	 * 
	 * @param name String
	 */
	public void checkPoint(String name) {
		this.checkPoints.add( new CheckPoint(name) ); 
	}
	
	/**
	 * Ends the last checkpoint
	 */
	public void endCheckPoint() {
		CheckPoint cp = (CheckPoint) this.checkPoints.lastElement();
		cp.end(); 		
	}
	
	/**
	 * Returns a printable representation of the debug results
	 * 
	 * @return String
	 */
	public String toString() {
		String result = String.format("<h3>The whole process took %10.3f milliseconds</h3>\n", this.duration() / 1E6 );
			
		int size = this.checkPoints.size();
		CheckPoint cp = null;
		
		for (int i = 0; i < size; i++) {
			
			cp = (CheckPoint) this.checkPoints.get(i);
				
			this.hystogram.add(cp);
				 
			result += cp.toString();			
		
		}
		
		result += this.hystogram.toString(this.duration());
		
		return result;
	}
	
	/**
	 * Returns the time difference
	 * @return String time difference in milliseconds
	 */
	public long duration() {
		return  this.endDate - this.startDate ;
	}
	
	/**
	 * Makes the application sleep
	 * 
	 * @param milliseconds int
	 */
	public void sleep(int milliseconds) {
		try {
			Thread.sleep(milliseconds);
		} catch (InterruptedException e){}		
	}	

}